==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/routing/product_skus_routing_spec.rb <==
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe ProductSkusController do
  describe "route generation" do
    it "maps #index" do
      route_for(:controller => "product_skus", :action => "index").should == "/product_skus"
    end
  
    it "maps #new" do
      route_for(:controller => "product_skus", :action => "new").should == "/product_skus/new"
    end
  
    it "maps #show" do
      route_for(:controller => "product_skus", :action => "show", :id => "1").should == "/product_skus/1"
    end
  
    it "maps #edit" do
      route_for(:controller => "product_skus", :action => "edit", :id => "1").should == "/product_skus/1/edit"
    end

  it "maps #create" do
    route_for(:controller => "product_skus", :action => "create").should == {:path => "/product_skus", :method => :post}
  end

  it "maps #update" do
    route_for(:controller => "product_skus", :action => "update", :id => "1").should == {:path =>"/product_skus/1", :method => :put}
  end
  
    it "maps #destroy" do
      route_for(:controller => "product_skus", :action => "destroy", :id => "1").should == {:path =>"/product_skus/1", :method => :delete}
    end
  end

  describe "route recognition" do
    it "generates params for #index" do
      params_from(:get, "/product_skus").should == {:controller => "product_skus", :action => "index"}
    end
  
    it "generates params for #new" do
      params_from(:get, "/product_skus/new").should == {:controller => "product_skus", :action => "new"}
    end
  
    it "generates params for #create" do
      params_from(:post, "/product_skus").should == {:controller => "product_skus", :action => "create"}
    end
  
    it "generates params for #show" do
      params_from(:get, "/product_skus/1").should == {:controller => "product_skus", :action => "show", :id => "1"}
    end
  
    it "generates params for #edit" do
      params_from(:get, "/product_skus/1/edit").should == {:controller => "product_skus", :action => "edit", :id => "1"}
    end
  
    it "generates params for #update" do
      params_from(:put, "/product_skus/1").should == {:controller => "product_skus", :action => "update", :id => "1"}
    end
  
    it "generates params for #destroy" do
      params_from(:delete, "/product_skus/1").should == {:controller => "product_skus", :action => "destroy", :id => "1"}
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/routing/product_skus_routing_spec.rb <==
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe ProductSkusController do
  describe "route generation" do
    it "maps #index" do
      route_for(:controller => "product_skus", :action => "index").should == "/product_skus"
    end
  
    it "maps #new" do
      route_for(:controller => "product_skus", :action => "new").should == "/product_skus/new"
    end
  
    it "maps #show" do
      route_for(:controller => "product_skus", :action => "show", :id => "1").should == "/product_skus/1/show"
    end
  
    it "maps #edit" do
      route_for(:controller => "product_skus", :action => "edit", :id => "1").should == "/product_skus/1/edit"
    end

  it "maps #create" do
    route_for(:controller => "product_skus", :action => "create").should == {:path => "/product_skus", :method => :post}
  end

  it "maps #update" do
    route_for(:controller => "product_skus", :action => "update", :id => "1").should == {:path =>"/product_skus/1/update", :method => :post}
  end
  
    it "maps #destroy" do
      route_for(:controller => "product_skus", :action => "destroy", :id => "1").should == {:path =>"/product_skus/1", :method => :delete}
    end
  end

  describe "route recognition" do
    it "generates params for #index" do
      params_from(:get, "/product_skus").should == {:controller => "product_skus", :action => "index"}
    end
  
    it "generates params for #new" do
      params_from(:get, "/product_skus/new").should == {:controller => "product_skus", :action => "new"}
    end
  
    it "generates params for #create" do
      params_from(:post, "/product_skus").should == {:controller => "product_skus", :action => "create"}
    end
  
    it "generates params for #show" do
      params_from(:get, "/product_skus/1").should == {:controller => "product_skus", :action => "show", :id => "1"}
    end
  
    it "generates params for #edit" do
      params_from(:get, "/product_skus/1/edit").should == {:controller => "product_skus", :action => "edit", :id => "1"}
    end
  
    it "generates params for #update" do
      params_from(:put, "/product_skus/1").should == {:controller => "product_skus", :action => "update", :id => "1"}
    end
  
    it "generates params for #destroy" do
      params_from(:delete, "/product_skus/1").should == {:controller => "product_skus", :action => "destroy", :id => "1"}
    end
  end
end
